@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """Top-level package for daops.
 daops - Dataset-Aware Operations"""
 
@@ -7,12 +6,12 @@ __author__ = """Elle Smith"""
 __contact__ = "eleanor.smith@stfc.ac.uk"
 __copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
 __license__ = "BSD"
-__version__ = "0.2.0"
+__version__ = "0.5.0"
 
-# from .utils import *
-# from .ops import (
-#     subset,
-# )
-# from .data_utils import (
-#     squeeze_dims
-# )
+from roocs_utils.config import get_config
+
+import daops
+
+CONFIG = get_config(daops)
+
+from clisops import logging
